@@ -70,6 +70,10 @@
 #line 19 "src/preproc/refer/label.ypp"
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "refer.h"
 #include "refid.h"
 #include "ref.h"
@@ -93,7 +97,7 @@ label_info *lookup_label(const string &label);
 struct expression {
   enum {
     // Does the tentative label depend on the reference?
-    CONTAINS_VARIABLE = 01, 
+    CONTAINS_VARIABLE = 01,
     CONTAINS_STAR = 02,
     CONTAINS_FORMAT = 04,
     CONTAINS_AT = 010
@@ -176,7 +180,7 @@ public:
   map_expr(expression *e, map_func *f) : unary_expr(e), func(f) { }
   void evaluate(int, const reference &, string &, substring_position &);
 };
-  
+
 typedef const char *extractor_func(const char *, const char *, const char **);
 
 class extractor_expr : public unary_expr {
@@ -192,7 +196,7 @@ public:
 class truncate_expr : public unary_expr {
   int n;
 public:
-  truncate_expr(expression *e, int i) : unary_expr(e), n(i) { } 
+  truncate_expr(expression *e, int i) : unary_expr(e), n(i) { }
   void evaluate(int, const reference &, string &, substring_position &);
 };
 
@@ -257,16 +261,16 @@ public:
   void evaluate(int, const reference &, string &, substring_position &);
 };
 
-static expression *parsed_label = 0;
-static expression *parsed_date_label = 0;
-static expression *parsed_short_label = 0;
+static expression *parsed_label = 0 /* nullptr */;
+static expression *parsed_date_label = 0 /* nullptr */;
+static expression *parsed_short_label = 0 /* nullptr */;
 
 static expression *parse_result;
 
 string literals;
 
 
-#line 270 "src/preproc/refer/label.cpp"
+#line 274 "src/preproc/refer/label.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -329,14 +333,14 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 218 "src/preproc/refer/label.ypp"
+#line 222 "src/preproc/refer/label.ypp"
 
   int num;
   expression *expr;
-  struct { int ndigits; int val; } dig;
-  struct { int start; int len; } str;
+  struct dig_s { int ndigits; int val; } dig;
+  struct str_s { int start; int len; } str;
 
-#line 340 "src/preproc/refer/label.cpp"
+#line 344 "src/preproc/refer/label.cpp"
 
 };
 typedef union YYSTYPE YYSTYPE;
@@ -775,10 +779,10 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   246,   246,   251,   253,   259,   260,   265,   267,   269,
-     274,   276,   281,   283,   288,   290,   295,   297,   299,   315,
-     319,   350,   352,   354,   356,   358,   364,   365,   370,   372,
-     377,   379,   386,   387,   389
+       0,   250,   250,   255,   257,   263,   264,   269,   271,   273,
+     278,   280,   285,   287,   292,   294,   299,   301,   303,   319,
+     323,   354,   356,   358,   360,   362,   368,   369,   374,   376,
+     381,   383,   390,   391,   393
 };
 #endif
 
@@ -1364,106 +1368,106 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* expr: optional_conditional  */
-#line 247 "src/preproc/refer/label.ypp"
+#line 251 "src/preproc/refer/label.ypp"
                 { parse_result = ((yyvsp[0].expr) ? new analyzed_expr((yyvsp[0].expr)) : 0); }
-#line 1370 "src/preproc/refer/label.cpp"
+#line 1374 "src/preproc/refer/label.cpp"
     break;
 
   case 3: /* conditional: alternative  */
-#line 252 "src/preproc/refer/label.ypp"
+#line 256 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = (yyvsp[0].expr); }
-#line 1376 "src/preproc/refer/label.cpp"
+#line 1380 "src/preproc/refer/label.cpp"
     break;
 
   case 4: /* conditional: alternative '?' optional_conditional ':' conditional  */
-#line 254 "src/preproc/refer/label.ypp"
+#line 258 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new conditional_expr((yyvsp[-4].expr), (yyvsp[-2].expr), (yyvsp[0].expr)); }
-#line 1382 "src/preproc/refer/label.cpp"
+#line 1386 "src/preproc/refer/label.cpp"
     break;
 
   case 5: /* optional_conditional: %empty  */
-#line 259 "src/preproc/refer/label.ypp"
+#line 263 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = 0; }
-#line 1388 "src/preproc/refer/label.cpp"
+#line 1392 "src/preproc/refer/label.cpp"
     break;
 
   case 6: /* optional_conditional: conditional  */
-#line 261 "src/preproc/refer/label.ypp"
+#line 265 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = (yyvsp[0].expr); }
-#line 1394 "src/preproc/refer/label.cpp"
+#line 1398 "src/preproc/refer/label.cpp"
     break;
 
   case 7: /* alternative: list  */
-#line 266 "src/preproc/refer/label.ypp"
+#line 270 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = (yyvsp[0].expr); }
-#line 1400 "src/preproc/refer/label.cpp"
+#line 1404 "src/preproc/refer/label.cpp"
     break;
 
   case 8: /* alternative: alternative '|' list  */
-#line 268 "src/preproc/refer/label.ypp"
+#line 272 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new alternative_expr((yyvsp[-2].expr), (yyvsp[0].expr)); }
-#line 1406 "src/preproc/refer/label.cpp"
+#line 1410 "src/preproc/refer/label.cpp"
     break;
 
   case 9: /* alternative: alternative '&' list  */
-#line 270 "src/preproc/refer/label.ypp"
+#line 274 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new conditional_expr((yyvsp[-2].expr), (yyvsp[0].expr), 0); }
-#line 1412 "src/preproc/refer/label.cpp"
+#line 1416 "src/preproc/refer/label.cpp"
     break;
 
   case 10: /* list: substitute  */
-#line 275 "src/preproc/refer/label.ypp"
+#line 279 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = (yyvsp[0].expr); }
-#line 1418 "src/preproc/refer/label.cpp"
+#line 1422 "src/preproc/refer/label.cpp"
     break;
 
   case 11: /* list: list substitute  */
-#line 277 "src/preproc/refer/label.ypp"
+#line 281 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new list_expr((yyvsp[-1].expr), (yyvsp[0].expr)); }
-#line 1424 "src/preproc/refer/label.cpp"
+#line 1428 "src/preproc/refer/label.cpp"
     break;
 
   case 12: /* substitute: string  */
-#line 282 "src/preproc/refer/label.ypp"
+#line 286 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = (yyvsp[0].expr); }
-#line 1430 "src/preproc/refer/label.cpp"
+#line 1434 "src/preproc/refer/label.cpp"
     break;
 
   case 13: /* substitute: substitute '~' string  */
-#line 284 "src/preproc/refer/label.ypp"
+#line 288 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new substitute_expr((yyvsp[-2].expr), (yyvsp[0].expr)); }
-#line 1436 "src/preproc/refer/label.cpp"
+#line 1440 "src/preproc/refer/label.cpp"
     break;
 
   case 14: /* string: '@'  */
-#line 289 "src/preproc/refer/label.ypp"
+#line 293 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new at_expr; }
-#line 1442 "src/preproc/refer/label.cpp"
+#line 1446 "src/preproc/refer/label.cpp"
     break;
 
   case 15: /* string: TOKEN_LITERAL  */
-#line 291 "src/preproc/refer/label.ypp"
+#line 295 "src/preproc/refer/label.ypp"
                 {
 		  (yyval.expr) = new literal_expr(literals.contents() + (yyvsp[0].str).start,
 					(yyvsp[0].str).len);
 		}
-#line 1451 "src/preproc/refer/label.cpp"
+#line 1455 "src/preproc/refer/label.cpp"
     break;
 
   case 16: /* string: TOKEN_LETTER  */
-#line 296 "src/preproc/refer/label.ypp"
+#line 300 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new field_expr((yyvsp[0].num), 0); }
-#line 1457 "src/preproc/refer/label.cpp"
+#line 1461 "src/preproc/refer/label.cpp"
     break;
 
   case 17: /* string: TOKEN_LETTER number  */
-#line 298 "src/preproc/refer/label.ypp"
+#line 302 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new field_expr((yyvsp[-1].num), (yyvsp[0].num) - 1); }
-#line 1463 "src/preproc/refer/label.cpp"
+#line 1467 "src/preproc/refer/label.cpp"
     break;
 
   case 18: /* string: '%' TOKEN_LETTER  */
-#line 300 "src/preproc/refer/label.ypp"
+#line 304 "src/preproc/refer/label.ypp"
                 {
 		  switch ((yyvsp[0].num)) {
 		  case 'I':
@@ -1478,19 +1482,19 @@ yyreduce:
 		    break;
 		  }
 		}
-#line 1482 "src/preproc/refer/label.cpp"
+#line 1486 "src/preproc/refer/label.cpp"
     break;
 
   case 19: /* string: '%' digits  */
-#line 316 "src/preproc/refer/label.ypp"
+#line 320 "src/preproc/refer/label.ypp"
                 {
 		  (yyval.expr) = new format_expr('0', (yyvsp[0].dig).ndigits, (yyvsp[0].dig).val);
 		}
-#line 1490 "src/preproc/refer/label.cpp"
+#line 1494 "src/preproc/refer/label.cpp"
     break;
 
   case 20: /* string: string '.' flag TOKEN_LETTER optional_number  */
-#line 320 "src/preproc/refer/label.ypp"
+#line 324 "src/preproc/refer/label.ypp"
                 {
 		  switch ((yyvsp[-1].num)) {
 		  case 'l':
@@ -1520,95 +1524,95 @@ yyreduce:
 		    break;
 		  }
 		}
-#line 1524 "src/preproc/refer/label.cpp"
+#line 1528 "src/preproc/refer/label.cpp"
     break;
 
   case 21: /* string: string '+' number  */
-#line 351 "src/preproc/refer/label.ypp"
+#line 355 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new truncate_expr((yyvsp[-2].expr), (yyvsp[0].num)); }
-#line 1530 "src/preproc/refer/label.cpp"
+#line 1534 "src/preproc/refer/label.cpp"
     break;
 
   case 22: /* string: string '-' number  */
-#line 353 "src/preproc/refer/label.ypp"
+#line 357 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new truncate_expr((yyvsp[-2].expr), -(yyvsp[0].num)); }
-#line 1536 "src/preproc/refer/label.cpp"
+#line 1540 "src/preproc/refer/label.cpp"
     break;
 
   case 23: /* string: string '*'  */
-#line 355 "src/preproc/refer/label.ypp"
+#line 359 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new star_expr((yyvsp[-1].expr)); }
-#line 1542 "src/preproc/refer/label.cpp"
+#line 1546 "src/preproc/refer/label.cpp"
     break;
 
   case 24: /* string: '(' optional_conditional ')'  */
-#line 357 "src/preproc/refer/label.ypp"
+#line 361 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = (yyvsp[-1].expr); }
-#line 1548 "src/preproc/refer/label.cpp"
+#line 1552 "src/preproc/refer/label.cpp"
     break;
 
   case 25: /* string: '<' optional_conditional '>'  */
-#line 359 "src/preproc/refer/label.ypp"
+#line 363 "src/preproc/refer/label.ypp"
                 { (yyval.expr) = new separator_expr((yyvsp[-1].expr)); }
-#line 1554 "src/preproc/refer/label.cpp"
+#line 1558 "src/preproc/refer/label.cpp"
     break;
 
   case 26: /* optional_number: %empty  */
-#line 364 "src/preproc/refer/label.ypp"
+#line 368 "src/preproc/refer/label.ypp"
                 { (yyval.num) = -1; }
-#line 1560 "src/preproc/refer/label.cpp"
+#line 1564 "src/preproc/refer/label.cpp"
     break;
 
   case 27: /* optional_number: number  */
-#line 366 "src/preproc/refer/label.ypp"
+#line 370 "src/preproc/refer/label.ypp"
                 { (yyval.num) = (yyvsp[0].num); }
-#line 1566 "src/preproc/refer/label.cpp"
+#line 1570 "src/preproc/refer/label.cpp"
     break;
 
   case 28: /* number: TOKEN_DIGIT  */
-#line 371 "src/preproc/refer/label.ypp"
+#line 375 "src/preproc/refer/label.ypp"
                 { (yyval.num) = (yyvsp[0].num); }
-#line 1572 "src/preproc/refer/label.cpp"
+#line 1576 "src/preproc/refer/label.cpp"
     break;
 
   case 29: /* number: number TOKEN_DIGIT  */
-#line 373 "src/preproc/refer/label.ypp"
+#line 377 "src/preproc/refer/label.ypp"
                 { (yyval.num) = (yyvsp[-1].num)*10 + (yyvsp[0].num); }
-#line 1578 "src/preproc/refer/label.cpp"
+#line 1582 "src/preproc/refer/label.cpp"
     break;
 
   case 30: /* digits: TOKEN_DIGIT  */
-#line 378 "src/preproc/refer/label.ypp"
+#line 382 "src/preproc/refer/label.ypp"
                 { (yyval.dig).ndigits = 1; (yyval.dig).val = (yyvsp[0].num); }
-#line 1584 "src/preproc/refer/label.cpp"
+#line 1588 "src/preproc/refer/label.cpp"
     break;
 
   case 31: /* digits: digits TOKEN_DIGIT  */
-#line 380 "src/preproc/refer/label.ypp"
+#line 384 "src/preproc/refer/label.ypp"
                 { (yyval.dig).ndigits = (yyvsp[-1].dig).ndigits + 1; (yyval.dig).val = (yyvsp[-1].dig).val*10 + (yyvsp[0].num); }
-#line 1590 "src/preproc/refer/label.cpp"
+#line 1594 "src/preproc/refer/label.cpp"
     break;
 
   case 32: /* flag: %empty  */
-#line 386 "src/preproc/refer/label.ypp"
+#line 390 "src/preproc/refer/label.ypp"
                 { (yyval.num) = 0; }
-#line 1596 "src/preproc/refer/label.cpp"
+#line 1600 "src/preproc/refer/label.cpp"
     break;
 
   case 33: /* flag: '+'  */
-#line 388 "src/preproc/refer/label.ypp"
+#line 392 "src/preproc/refer/label.ypp"
                 { (yyval.num) = 1; }
-#line 1602 "src/preproc/refer/label.cpp"
+#line 1606 "src/preproc/refer/label.cpp"
     break;
 
   case 34: /* flag: '-'  */
-#line 390 "src/preproc/refer/label.ypp"
+#line 394 "src/preproc/refer/label.ypp"
                 { (yyval.num) = -1; }
-#line 1608 "src/preproc/refer/label.cpp"
+#line 1612 "src/preproc/refer/label.cpp"
     break;
 
 
-#line 1612 "src/preproc/refer/label.cpp"
+#line 1616 "src/preproc/refer/label.cpp"
 
       default: break;
     }
@@ -1801,7 +1805,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 393 "src/preproc/refer/label.ypp"
+#line 397 "src/preproc/refer/label.ypp"
 
 
 /* bison defines const to be empty unless __STDC__ is defined, which it
@@ -1821,7 +1825,7 @@ static char uppercase_array[] = {
   'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X',
   'Y', 'Z',
 };
-  
+
 static char lowercase_array[] = {
   'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h',
   'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p',
@@ -1933,7 +1937,7 @@ void format_expr::evaluate(int tentative, const reference &ref,
     result += format_serial(type, num + 1);
   else {
     const char *ptr = i_to_a(num + first_number);
-    int pad = width - strlen(ptr);
+    ptrdiff_t pad = width - strlen(ptr);
     while (--pad >= 0)
       result += '0';
     result += ptr;
@@ -2028,7 +2032,7 @@ static const char *format_serial(char c, int n)
       break;
     }
   default:
-    assert(0);
+    assert(0 == "unhandled case of register format");
   }
   return buf;
 }
@@ -2123,7 +2127,7 @@ void extractor_expr::evaluate(int tentative, const reference &ref,
 	result.append(end, temp.contents() + temp.length() - end);
       break;
     default:
-      assert(0);
+      assert(0 == "unhandled case of part in expression evaluator");
     }
   }
 }
@@ -2317,7 +2321,7 @@ const substring_position &reference::get_separator_pos(label_type type) const
 const string &reference::get_label(label_type type) const
 {
   if (type == SHORT_LABEL && short_label_flag)
-    return short_label; 
+    return short_label;
   else
     return label;
 }
@@ -2330,7 +2334,7 @@ int reference::merge_labels_by_parts(reference **v, int n, label_type type,
   const string &lb = get_label(type);
   const substring_position &sp = get_separator_pos(type);
   if (sp.start < 0
-      || sp.start != v[0]->get_separator_pos(type).start 
+      || sp.start != v[0]->get_separator_pos(type).start
       || memcmp(lb.contents(), v[0]->get_label(type).contents(),
 		sp.start) != 0)
     return 0;
